@@ -171,7 +171,10 @@ class TP_Importer(Excel_Importer):
                                 row_data[key] = ""
                         else:
                             try:
-                                row_data[key] = row[col_nr].value
+                                if type(row[col_nr].value) == str:
+                                    row_data[key] = str(row[col_nr].value).strip()
+                                else:
+                                    row_data[key] = row[col_nr].value
                             except:
                                 row_data[key] = ""
                     tp_data.append(row_data)
